#
# spec file for package human-theme-gtk
#
# Copyright (c) 2021-2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           human-theme-gtk
Version:        2.4.0
Release:        bp156.2.9.1
Summary:        Human theme for GTK
Summary(fr):    Thème Human pour GTK
License:        GPL-3.0-or-later AND LGPL-2.1-or-later AND CC-BY-SA-3.0
URL:            https://github.com/luigifab/human-theme
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  aspell-fr
Recommends:     dmz-icon-theme-cursors
Recommends:     gnome-icon-theme
Recommends:     gtk2-engine-murrine
Suggests:       libqt5-qtbase-platformtheme-gtk3
Suggests:       libqt5-qtstyleplugins-platformtheme-gtk2
Suggests:       qt6-platformtheme-gtk3
# https://software.opensuse.org/search?baseproject=openSUSE%3AFactory&q=qt+theme+gtk
BuildArch:      noarch

%description %{expand:
This theme works with GTK 2.24 (with gtk2-engine-murrine),
3.24, and 4.12. Better rendering with Pango 1.42- or 1.51+.

It is mainly intended for MATE and Xfce desktop environments.
After installation you must restart your session.}

%description -l fr %{expand:
Ce thème fonctionne avec : GTK 2.24 (avec gtk2-engine-murrine),
3.24, et 4.12. Meilleur rendu avec Pango 1.42- ou 1.51+.

Il est principalement destiné pour les environnements de bureau MATE et Xfce.
Après l'installation vous devez redémarrer votre session.}

%prep
%setup -q -n human-theme-%{version}
sed -i 's/IconTheme=gnome/IconTheme=mate/g' src/*/index.theme

%install
install -dm 755 %{buildroot}%{_datadir}/themes/
cp -a src/human-theme/           %{buildroot}%{_datadir}/themes/
cp -a src/human-theme-blue/      %{buildroot}%{_datadir}/themes/
cp -a src/human-theme-green/     %{buildroot}%{_datadir}/themes/
cp -a src/human-theme-orange/    %{buildroot}%{_datadir}/themes/
install -Dpm 644 data/profile.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh

%files
%config(noreplace) %{_sysconfdir}/profile.d/%{name}.sh
%license LICENSE
%doc README.md
# the entire source code is GPL-3.0-or-later, except */metacity-1/* which is LGPL-2.1-or-later,
# and */gtk-2.0/* which is CC-BY-SA-3.0-or-later
%{_datadir}/themes/human-theme/
%{_datadir}/themes/human-theme-blue/
%{_datadir}/themes/human-theme-green/
%{_datadir}/themes/human-theme-orange/

%changelog
* Mon May  5 2025 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.4.0)
  * (gtk 3 & 4) fix/update design of headerbar
  * (gtk 3 & 4) fix/update design of CSD window
  * (gtk 3 & 4) fix position of check/radio in menuitem
  * (gtk 3 & 4) fix rtl menu with only check/radio
  * (gtk 3) fix/update design for Mate notifications
    PR => github.com/mate-desktop/mate-notification-daemon/pull/232
    PR => github.com/mate-desktop/mate-notification-daemon/pull/233
    PR => github.com/mate-desktop/mate-notification-daemon/pull/234
- It works: with or without compositor, with or without CSD windows
  and with or without gtk3-classic/gtk4-classic
- The best with gtk3-classic and gtk4-classic
    gist.github.com/luigifab/0fce786cdb93b5687069a82f490ea95e
  * (gtk 3 & 4) automatic min-width/min-height from text for
    progressbars, with dual text color, without excessive cpu usage
* Fri Apr  4 2025 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.3.0)
  * (gtk 3) new design for Mate notifications
    PR => github.com/mate-desktop/mate-notification-daemon/pull/232
    PR => github.com/mate-desktop/mate-notification-daemon/pull/233
    mate-notification-daemon v1.28.4+
  * (gtk 3) fix design for Bleachbit
    PR => github.com/bleachbit/bleachbit/pull/1195
    bleachbit v?
  * (gtk 3) update design for mate-control-center & ccsm
  * (gtk 3) fix icon size in titlebar for xfwm4
  * (gtk 3) fix padding in titlebar when maximized for xfwm4
  * (gtk 3) same design between Mate and Xfce for terminal & alttab
    PR => github.com/mate-desktop/marco/pull/789
    marco v1.28.2+
  * (gtk 3) update font color for mate-panel
  * (gtk 3) fix font color for mate keyboard indicator
  * (gtk 3) fix background for disabled view for Caja (F3)
  * (gtk 3) fix lines (treeview) for disabled view for Caja (F3)
  * (gtk 3) fix design of progressbar in statusbar for Eom
  * (gtk 3) fix design for Mate osd when compositor is enabled
  * (gtk 3 & 4) fix design of progressbars with text in statusbar
  * (gtk 3 & 4) fix and update design of progressbars with text
  * (gtk 3 & 4) update background for selected lines in treeviews
  * (gtk 3 & 4) add highlight effect for icons on hover
  * (gtk 3 & 4) better contrast for progressbars/scales background
  * (gtk 3 & 4) little enhancement for headarbar
  * (gtk 4) fix for the stupid hover effect on menubar items
  * (gtk 4) fix background of menu items
  * (gtk 4) add design for listviews (open/save dialogs)
  * (gtk 4) add design open/save dialogs
  * (gtk 4) no changes required from 4.12 to 4.18!
- The best with gtk3-classic and gtk4-classic
    gist.github.com/luigifab/0fce786cdb93b5687069a82f490ea95e
  * (gtk 3) automatic min-width/min-height for progressbars
  * (gtk 4) add dual text color for progressbars
* Mon Mar  3 2025 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.2.1)
  * packages scripts update
  * (gtk 3 & 4) update style for Thunar (same as Caja)
* Fri Feb  2 2024 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.2.0)
  * (gtk 3) dual text color for progress bars is back
    with appearance__progress_text.gtk3.patch for gtk3-classic
  * (gtk 3) add gtk standard color names
  * (gtk 3 & 4) add style for statusbar in progressbar and toolbar
  * (gtk 3 & 4) update style for progressbar in treeviews
  * (gtk 3 & 4) update style for arrows of notebook tabs
  * (gtk 4) compatibility only with 4.12
* Tue Oct 10 2023 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.1.0)
  * (gtk 3 & 4) small fix for geany messages window
  * (gtk 3 & 4) almost same rendering between pango 1.42 and 1.51
  * (gtk 4) compatibility with 4.12
* Fri Jun 16 2023 Fabrice Creuzot <code@luigifab.fr>
- Package spec update
* Tue Jun  6 2023 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (2.0.0)
  * (gtk 3) alternating row colours in tree views is back
  * Xfce users have now decorations for windows
  * Mate users will enjoy better styles for lock screen and OSD
  * Mate users have now styles for window selector and date/hour
    applets when clicked
  * status bar styles works with or without gtk3-classic
  * added styles for CSD windows
* Thu Sep  9 2021 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (1.5.0)
  * (gtk 3 & 4) fix text color for image settings of print dialog
  * (gtk 3) set background color for RTL scales
  * (gtk 4) set vertical scale marks position
* Wed Jul  7 2021 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (1.4.0)
  * (gtk 3 & 4) fix style for disabled switchs, spinbuttons, images
  * (gtk 3 & 4) fix text color for progressbars in treeviews
  * (gtk 3 & 4) fix credits and license borders in about dialogs
  * (gtk 3 & 4) set same focused border color (outline)
  * (gtk 3 & 4) add border for focused scales (outline)
  * (gtk 3 & 4) add style for disabled toggle buttons in toolbars
  * (gtk 3 & 4) add RTL styles
  * (gtk 3) fix right click menu style for mate-calc and gedit
  * (gtk 3) remove borders separators for mate window
    selector applet
  * (gtk 4) refactor style of toolbar buttons and scales
* Wed May  5 2021 Fabrice Creuzot <code@luigifab.fr>
- New upstream release (1.3.0)
  * (gtk3 & 4) new style for switch buttons
  * (gtk3 & 4) new style for scales (for 0%% and 100%%)
  * (gtk3 & 4) set style for selection box (rubberband)
  * (gtk3 & 4) set style for check, radio, progress and icon
    widgets in treeviews
  * (gtk3) fix menuitems style for mate-calc
  * (gtk3) fix selected days style in calendars
  * (gtk4) set style for menuitems
  * (gtk4) set style for calendars
  * (gtk4) set style for toolbar buttons (without flat class)
* Tue Apr  6 2021 Fabrice Creuzot <code@luigifab.fr>
- Initial openSUSE package release
